diff --git a/docs/RepositoryApi.md b/docs/RepositoryApi.md
index f82aba0..0c57e7e 100644
--- a/docs/RepositoryApi.md
+++ b/docs/RepositoryApi.md
@@ -174,6 +174,7 @@ Method | HTTP request | Description
[**repoPullRequestIsMerged**](RepositoryApi.md#repoPullRequestIsMerged) | **GET** repos/{owner}/{repo}/pulls/{index}/merge | Check if a pull request has been merged
[**repoPushMirrorSync**](RepositoryApi.md#repoPushMirrorSync) | **POST** repos/{owner}/{repo}/push_mirrors-sync | Sync all push mirrored repository
[**repoRenameBranch**](RepositoryApi.md#repoRenameBranch) | **PATCH** repos/{owner}/{repo}/branches/{branch} | Rename a branch
+[**repoResolvePullReviewComment**](RepositoryApi.md#repoResolvePullReviewComment) | **POST** repos/{owner}/{repo}/pulls/comments/{id}/resolve | Resolve a pull request review comment
[**repoSearch**](RepositoryApi.md#repoSearch) | **GET** repos/search | Search for repositories
[**repoSigningKey**](RepositoryApi.md#repoSigningKey) | **GET** repos/{owner}/{repo}/signing-key.gpg | Get signing-key.gpg for given repository
[**repoSigningKeySSH**](RepositoryApi.md#repoSigningKeySSH) | **GET** repos/{owner}/{repo}/signing-key.pub | Get signing-key.pub for given repository
@@ -182,6 +183,7 @@ Method | HTTP request | Description
[**repoTrackedTimes**](RepositoryApi.md#repoTrackedTimes) | **GET** repos/{owner}/{repo}/times | List a repo's tracked times
[**repoTransfer**](RepositoryApi.md#repoTransfer) | **POST** repos/{owner}/{repo}/transfer | Transfer a repo ownership
[**repoUnDismissPullReview**](RepositoryApi.md#repoUnDismissPullReview) | **POST** repos/{owner}/{repo}/pulls/{index}/reviews/{id}/undismissals | Cancel to dismiss a review for a pull request
+[**repoUnresolvePullReviewComment**](RepositoryApi.md#repoUnresolvePullReviewComment) | **POST** repos/{owner}/{repo}/pulls/comments/{id}/unresolve | Unresolve a pull request review comment
[**repoUpdateAvatar**](RepositoryApi.md#repoUpdateAvatar) | **POST** repos/{owner}/{repo}/avatar | Update avatar
[**repoUpdateBranch**](RepositoryApi.md#repoUpdateBranch) | **PUT** repos/{owner}/{repo}/branches/{branch} | Update a branch reference to a new commit
[**repoUpdateBranchProtectionPriories**](RepositoryApi.md#repoUpdateBranchProtectionPriories) | **POST** repos/{owner}/{repo}/branch_protections/priority | Update the priorities of branch protections for a repository.
@@ -15948,6 +15950,97 @@ Name | Type | Description | Notes
- **Content-Type**: application/json
- **Accept**: Not defined
+
+# **repoResolvePullReviewComment**
+> Void repoResolvePullReviewComment(owner, repo, id)
+
+Resolve a pull request review comment
+
+### Example
+```java
+// Import classes:
+//import org.gitnex.tea4j.v2.ApiClient;
+//import org.gitnex.tea4j.v2.ApiException;
+//import org.gitnex.tea4j.v2.Configuration;
+//import org.gitnex.tea4j.v2.auth.*;
+//import org.gitnex.tea4j.v2.apis.RepositoryApi;
+
+ApiClient defaultClient = Configuration.getDefaultApiClient();
+
+// Configure API key authorization: AccessToken
+ApiKeyAuth AccessToken = (ApiKeyAuth) defaultClient.getAuthentication("AccessToken");
+AccessToken.setApiKey("YOUR API KEY");
+// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
+//AccessToken.setApiKeyPrefix("Token");
+
+// Configure API key authorization: AuthorizationHeaderToken
+ApiKeyAuth AuthorizationHeaderToken = (ApiKeyAuth) defaultClient.getAuthentication("AuthorizationHeaderToken");
+AuthorizationHeaderToken.setApiKey("YOUR API KEY");
+// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
+//AuthorizationHeaderToken.setApiKeyPrefix("Token");
+// Configure HTTP basic authorization: BasicAuth
+HttpBasicAuth BasicAuth = (HttpBasicAuth) defaultClient.getAuthentication("BasicAuth");
+BasicAuth.setUsername("YOUR USERNAME");
+BasicAuth.setPassword("YOUR PASSWORD");
+
+// Configure API key authorization: SudoHeader
+ApiKeyAuth SudoHeader = (ApiKeyAuth) defaultClient.getAuthentication("SudoHeader");
+SudoHeader.setApiKey("YOUR API KEY");
+// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
+//SudoHeader.setApiKeyPrefix("Token");
+
+// Configure API key authorization: SudoParam
+ApiKeyAuth SudoParam = (ApiKeyAuth) defaultClient.getAuthentication("SudoParam");
+SudoParam.setApiKey("YOUR API KEY");
+// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
+//SudoParam.setApiKeyPrefix("Token");
+
+// Configure API key authorization: TOTPHeader
+ApiKeyAuth TOTPHeader = (ApiKeyAuth) defaultClient.getAuthentication("TOTPHeader");
+TOTPHeader.setApiKey("YOUR API KEY");
+// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
+//TOTPHeader.setApiKeyPrefix("Token");
+
+// Configure API key authorization: Token
+ApiKeyAuth Token = (ApiKeyAuth) defaultClient.getAuthentication("Token");
+Token.setApiKey("YOUR API KEY");
+// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
+//Token.setApiKeyPrefix("Token");
+
+RepositoryApi apiInstance = new RepositoryApi();
+String owner = "owner_example"; // String | owner of the repo
+String repo = "repo_example"; // String | name of the repo
+Long id = 789L; // Long | id of the review comment
+try {
+ Void result = apiInstance.repoResolvePullReviewComment(owner, repo, id);
+ System.out.println(result);
+} catch (ApiException e) {
+ System.err.println("Exception when calling RepositoryApi#repoResolvePullReviewComment");
+ e.printStackTrace();
+}
+```
+
+### Parameters
+
+Name | Type | Description | Notes
+------------- | ------------- | ------------- | -------------
+ **owner** | **String**| owner of the repo |
+ **repo** | **String**| name of the repo |
+ **id** | **Long**| id of the review comment |
+
+### Return type
+
+[**Void**](.md)
+
+### Authorization
+
+[AccessToken](../README.md#AccessToken)[AuthorizationHeaderToken](../README.md#AuthorizationHeaderToken)[BasicAuth](../README.md#BasicAuth)[SudoHeader](../README.md#SudoHeader)[SudoParam](../README.md#SudoParam)[TOTPHeader](../README.md#TOTPHeader)[Token](../README.md#Token)
+
+### HTTP request headers
+
+ - **Content-Type**: Not defined
+ - **Accept**: Not defined
+
# **repoSearch**
> SearchResults repoSearch(q, topic, includeDesc, uid, priorityOwnerId, teamId, starredBy, _private, isPrivate, template, archived, mode, exclusive, sort, order, page, limit)
@@ -16716,6 +16809,97 @@ Name | Type | Description | Notes
- **Content-Type**: Not defined
- **Accept**: application/json
+
+# **repoUnresolvePullReviewComment**
+> Void repoUnresolvePullReviewComment(owner, repo, id)
+
+Unresolve a pull request review comment
+
+### Example
+```java
+// Import classes:
+//import org.gitnex.tea4j.v2.ApiClient;
+//import org.gitnex.tea4j.v2.ApiException;
+//import org.gitnex.tea4j.v2.Configuration;
+//import org.gitnex.tea4j.v2.auth.*;
+//import org.gitnex.tea4j.v2.apis.RepositoryApi;
+
+ApiClient defaultClient = Configuration.getDefaultApiClient();
+
+// Configure API key authorization: AccessToken
+ApiKeyAuth AccessToken = (ApiKeyAuth) defaultClient.getAuthentication("AccessToken");
+AccessToken.setApiKey("YOUR API KEY");
+// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
+//AccessToken.setApiKeyPrefix("Token");
+
+// Configure API key authorization: AuthorizationHeaderToken
+ApiKeyAuth AuthorizationHeaderToken = (ApiKeyAuth) defaultClient.getAuthentication("AuthorizationHeaderToken");
+AuthorizationHeaderToken.setApiKey("YOUR API KEY");
+// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
+//AuthorizationHeaderToken.setApiKeyPrefix("Token");
+// Configure HTTP basic authorization: BasicAuth
+HttpBasicAuth BasicAuth = (HttpBasicAuth) defaultClient.getAuthentication("BasicAuth");
+BasicAuth.setUsername("YOUR USERNAME");
+BasicAuth.setPassword("YOUR PASSWORD");
+
+// Configure API key authorization: SudoHeader
+ApiKeyAuth SudoHeader = (ApiKeyAuth) defaultClient.getAuthentication("SudoHeader");
+SudoHeader.setApiKey("YOUR API KEY");
+// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
+//SudoHeader.setApiKeyPrefix("Token");
+
+// Configure API key authorization: SudoParam
+ApiKeyAuth SudoParam = (ApiKeyAuth) defaultClient.getAuthentication("SudoParam");
+SudoParam.setApiKey("YOUR API KEY");
+// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
+//SudoParam.setApiKeyPrefix("Token");
+
+// Configure API key authorization: TOTPHeader
+ApiKeyAuth TOTPHeader = (ApiKeyAuth) defaultClient.getAuthentication("TOTPHeader");
+TOTPHeader.setApiKey("YOUR API KEY");
+// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
+//TOTPHeader.setApiKeyPrefix("Token");
+
+// Configure API key authorization: Token
+ApiKeyAuth Token = (ApiKeyAuth) defaultClient.getAuthentication("Token");
+Token.setApiKey("YOUR API KEY");
+// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
+//Token.setApiKeyPrefix("Token");
+
+RepositoryApi apiInstance = new RepositoryApi();
+String owner = "owner_example"; // String | owner of the repo
+String repo = "repo_example"; // String | name of the repo
+Long id = 789L; // Long | id of the review comment
+try {
+ Void result = apiInstance.repoUnresolvePullReviewComment(owner, repo, id);
+ System.out.println(result);
+} catch (ApiException e) {
+ System.err.println("Exception when calling RepositoryApi#repoUnresolvePullReviewComment");
+ e.printStackTrace();
+}
+```
+
+### Parameters
+
+Name | Type | Description | Notes
+------------- | ------------- | ------------- | -------------
+ **owner** | **String**| owner of the repo |
+ **repo** | **String**| name of the repo |
+ **id** | **Long**| id of the review comment |
+
+### Return type
+
+[**Void**](.md)
+
+### Authorization
+
+[AccessToken](../README.md#AccessToken)[AuthorizationHeaderToken](../README.md#AuthorizationHeaderToken)[BasicAuth](../README.md#BasicAuth)[SudoHeader](../README.md#SudoHeader)[SudoParam](../README.md#SudoParam)[TOTPHeader](../README.md#TOTPHeader)[Token](../README.md#Token)
+
+### HTTP request headers
+
+ - **Content-Type**: Not defined
+ - **Accept**: Not defined
+
# **repoUpdateAvatar**
> Void repoUpdateAvatar(owner, repo, body)
diff --git a/src/main/java/org/gitnex/tea4j/v2/apis/RepositoryApi.java b/src/main/java/org/gitnex/tea4j/v2/apis/RepositoryApi.java
index c20d078..d582ade 100644
--- a/src/main/java/org/gitnex/tea4j/v2/apis/RepositoryApi.java
+++ b/src/main/java/org/gitnex/tea4j/v2/apis/RepositoryApi.java
@@ -2752,6 +2752,20 @@ public interface RepositoryApi {
@retrofit2.http.Path("branch") String branch,
@retrofit2.http.Body RenameBranchRepoOption body);
+ /**
+ * Resolve a pull request review comment
+ *
+ * @param owner owner of the repo (required)
+ * @param repo name of the repo (required)
+ * @param id id of the review comment (required)
+ * @return Call<Void>
+ */
+ @POST("repos/{owner}/{repo}/pulls/comments/{id}/resolve")
+ Call repoResolvePullReviewComment(
+ @retrofit2.http.Path("owner") String owner,
+ @retrofit2.http.Path("repo") String repo,
+ @retrofit2.http.Path("id") Long id);
+
/**
* Search for repositories
*
@@ -2918,6 +2932,20 @@ public interface RepositoryApi {
@retrofit2.http.Path("index") Long index,
@retrofit2.http.Path("id") Long id);
+ /**
+ * Unresolve a pull request review comment
+ *
+ * @param owner owner of the repo (required)
+ * @param repo name of the repo (required)
+ * @param id id of the review comment (required)
+ * @return Call<Void>
+ */
+ @POST("repos/{owner}/{repo}/pulls/comments/{id}/unresolve")
+ Call repoUnresolvePullReviewComment(
+ @retrofit2.http.Path("owner") String owner,
+ @retrofit2.http.Path("repo") String repo,
+ @retrofit2.http.Path("id") Long id);
+
/**
* Update avatar
*
diff --git a/src/main/java/org/gitnex/tea4j/v2/models/PullReviewRequestOptions.java b/src/main/java/org/gitnex/tea4j/v2/models/PullReviewRequestOptions.java
index 67a0aed..3bf9145 100644
--- a/src/main/java/org/gitnex/tea4j/v2/models/PullReviewRequestOptions.java
+++ b/src/main/java/org/gitnex/tea4j/v2/models/PullReviewRequestOptions.java
@@ -19,8 +19,10 @@ import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
-/** PullReviewRequestOptions are options to add or remove pull review requests */
-@Schema(description = "PullReviewRequestOptions are options to add or remove pull review requests")
+/** PullReviewRequestOptions are options to add or remove pull request review requests */
+@Schema(
+ description =
+ "PullReviewRequestOptions are options to add or remove pull request review requests")
public class PullReviewRequestOptions implements Serializable {
private static final long serialVersionUID = 1L;
diff --git a/src/main/java/org/gitnex/tea4j/v2/models/CreatePullReviewOptions.java b/src/main/java/org/gitnex/tea4j/v2/models/CreatePullReviewOptions.java
index a2bdf4e..244e7dc 100644
--- a/src/main/java/org/gitnex/tea4j/v2/models/CreatePullReviewOptions.java
+++ b/src/main/java/org/gitnex/tea4j/v2/models/CreatePullReviewOptions.java
@@ -19,8 +19,8 @@ import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
-/** CreatePullReviewOptions are options to create a pull review */
-@Schema(description = "CreatePullReviewOptions are options to create a pull review")
+/** CreatePullReviewOptions are options to create a pull request review */
+@Schema(description = "CreatePullReviewOptions are options to create a pull request review")
public class CreatePullReviewOptions implements Serializable {
private static final long serialVersionUID = 1L;
diff --git a/src/main/java/org/gitnex/tea4j/v2/models/DismissPullReviewOptions.java b/src/main/java/org/gitnex/tea4j/v2/models/DismissPullReviewOptions.java
index 20c34e2..272a4c9 100644
--- a/src/main/java/org/gitnex/tea4j/v2/models/DismissPullReviewOptions.java
+++ b/src/main/java/org/gitnex/tea4j/v2/models/DismissPullReviewOptions.java
@@ -17,8 +17,8 @@ import io.swagger.v3.oas.annotations.media.Schema;
import java.io.Serializable;
import java.util.Objects;
-/** DismissPullReviewOptions are options to dismiss a pull review */
-@Schema(description = "DismissPullReviewOptions are options to dismiss a pull review")
+/** DismissPullReviewOptions are options to dismiss a pull request review */
+@Schema(description = "DismissPullReviewOptions are options to dismiss a pull request review")
public class DismissPullReviewOptions implements Serializable {
private static final long serialVersionUID = 1L;
diff --git a/src/main/java/org/gitnex/tea4j/v2/models/SubmitPullReviewOptions.java b/src/main/java/org/gitnex/tea4j/v2/models/SubmitPullReviewOptions.java
index a80a8d8..a9bd10c 100644
--- a/src/main/java/org/gitnex/tea4j/v2/models/SubmitPullReviewOptions.java
+++ b/src/main/java/org/gitnex/tea4j/v2/models/SubmitPullReviewOptions.java
@@ -17,8 +17,8 @@ import io.swagger.v3.oas.annotations.media.Schema;
import java.io.Serializable;
import java.util.Objects;
-/** SubmitPullReviewOptions are options to submit a pending pull review */
-@Schema(description = "SubmitPullReviewOptions are options to submit a pending pull review")
+/** SubmitPullReviewOptions are options to submit a pending pull request review */
+@Schema(description = "SubmitPullReviewOptions are options to submit a pending pull request review")
public class SubmitPullReviewOptions implements Serializable {
private static final long serialVersionUID = 1L;